@@ -16,7 +16,7 @@ use Config::Std;
 use Data::Dumper qw/Dumper/;
 use SVG::Calendar;
 
-our $VERSION = version->new('0.3.3');
+our $VERSION = version->new('0.3.4');
 
 my %option = (
     moon     => {},
@@ -67,10 +67,14 @@ sub main {
         print "svgcal.pl Version = $VERSION\n";
         exit 1;
     }
-    if ( $option{man} ) {
+    elsif ( $option{man} ) {
         pod2usage( -verbose => 2 );
     }
-    if ( $option{help} ) {
+    elsif ( $option{help} ) {
+        pod2usage( -verbose => 1 );
+    }
+    elsif ( $option{date} ) {
+        warn "No dates specified, nothing to do!\n";
         pod2usage( -verbose => 1 );
     }
 
@@ -283,7 +287,7 @@ svgcal.pl - Creates the pages for a calendar in SVG format
 
 =head1 VERSION
 
-This documentation refers to svgcal.pl version 0.3.3.
+This documentation refers to svgcal.pl version 0.3.4.
 
 =head1 SYNOPSIS
 
